projectal.entities.rebate API documentation

# projectal.entities.rebate

View Source

    from projectal.entity import Entity
    from projectal.linkers import *

    class Rebate(Entity, ProjectLinker, TaskLinker, TaskTemplateLinker, NoteLinker):
        """
        Implementation of the [Rebate](https://projectal.com/docs/latest/#tag/Rebate) API.
        """
        _path = 'rebate'
        _name = 'rebate'
        _links = [NoteLinker]
        _links_reverse = [ProjectLinker, TaskLinker, TaskTemplateLinker]

class Rebate(projectal.entity.Entity, projectal.linkers.ProjectLinker, projectal.linkers.TaskLinker, projectal.linkers.TaskTemplateLinker, projectal.linkers.NoteLinker):
View Source

    class Rebate(Entity, ProjectLinker, TaskLinker, TaskTemplateLinker, NoteLinker):
        """
        Implementation of the [Rebate](https://projectal.com/docs/latest/#tag/Rebate) API.
        """
        _path = 'rebate'
        _name = 'rebate'
        _links = [NoteLinker]
        _links_reverse = [ProjectLinker, TaskLinker, TaskTemplateLinker]

Implementation of the Rebate API.

##### Inherited Members

projectal.entity.Entity
  Entity
  get
  update
  delete
  history
  create
  save
  clone
  list
  match
  match_startswith
  match_endswith
  match_one
  match_startswith_one
  match_endswith_one
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
  entity_name
projectal.linkers.ProjectLinker
  link_project
  unlink_project
projectal.linkers.TaskLinker
  link_task
  unlink_task
projectal.linkers.TaskTemplateLinker
  link_task_template
  unlink_task_template
builtins.dict
  setdefault
  pop
  popitem
  keys
  items
  values
  fromkeys
  clear
  copy